pub enum CommittedStatus {
Committed {
tx_seq: u64,
},
Rejected {
error_code: RejectedErrorCode,
},
}Expand description
Determined command outcome.
Variants
Committed
Determined final outcome with state delta and allocated tx_seq.
Rejected
Determined final outcome without state delta but still tied to the
command’s accepted ext_seq.
Fields

error_code: RejectedErrorCodeTrait Implementations
Sourceimpl Clone for CommittedStatus
impl Clone for CommittedStatus
Sourcefn clone(&self) -> CommittedStatus
fn clone(&self) -> CommittedStatus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommittedStatus
impl Debug for CommittedStatus
Sourceimpl PartialEq for CommittedStatus
impl PartialEq for CommittedStatus
impl Copy for CommittedStatus
impl Eq for CommittedStatus
impl StructuralPartialEq for CommittedStatus