QueueCodecError

Enum QueueCodecError 

pub enum QueueCodecError {
    Truncated,
    TrailingBytes {
        expected: usize,
        actual: usize,
    },
    FieldTooLarge {
        field: &'static str,
        len: u64,
    },
    UnsupportedVersion {
        expected: u8,
        found: u8,
    },
    InvalidFieldValue {
        field: &'static str,
        value: u64,
    },
}
Error returned when queue codec records cannot be encoded or decoded.

Variants



Truncated

Input ended before all required fields were present.



TrailingBytes

Input had extra bytes after the expected record length.

Fields

expected: usize
actual: usize


FieldTooLarge

A field length does not fit the codec.

Fields

field: &'static str
len: u64


UnsupportedVersion

Record version does not match this codec.

Fields

expected: u8
found: u8


InvalidFieldValue

Field value is not in the valid domain.

Fields

field: &'static str
value: u64