runtime_plugin_create_runtime_v1

Function runtime_plugin_create_runtime_v1 

pub unsafe fn runtime_plugin_create_runtime_v1(
    factory: fn() -> Box<dyn RuntimePluginFactory>,
    config: RuntimeBytesRef,
    out_runtime: *mut *mut c_void,
    out_error: *mut RuntimeErrorBuf,
) -> RuntimeCallStatus
Creates a runtime plugin instance through the v1 ABI helper.

Safety

out_runtime and out_error, when non-null, must be valid for writes for the duration of the call. config must point to bytes that remain valid for the duration of the call.