runtime_plugin_run_tx_v1

Function runtime_plugin_run_tx_v1 

pub unsafe fn runtime_plugin_run_tx_v1(
    runtime: *mut c_void,
    host: RuntimeHostContextV1,
    command: RuntimeCommandView,
    out_error: *mut RuntimeErrorBuf,
) -> RuntimeCallStatus
Runs one command transaction through the v1 ABI helper.

Safety

runtime must be a live plugin handle, host must contain a valid host context and vtable for the duration of the call, and command.payload and out_error must remain valid for the duration of the call.