QueueReceipt

Struct QueueReceipt 

pub struct QueueReceipt {
    pub ext_seq: u64,
}
Receipt returned when a command is accepted by the queue.

Fields

ext_seq: u64

Queue-level acceptance identifier assigned when the command is accepted.